==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sesv2/kotlin/inputs/ConfigurationSetVdmOptionsGuardianOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sesv2.kotlin.inputs

import com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property optimizedSharedDelivery Specifies the status of your VDM optimized shared delivery. Valid values: `ENABLED`, `DISABLED`.
 */
public data class ConfigurationSetVdmOptionsGuardianOptionsArgs(
    public val optimizedSharedDelivery: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs> {
    override fun toJava(): com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs =
        com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs.builder()
            .optimizedSharedDelivery(optimizedSharedDelivery?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConfigurationSetVdmOptionsGuardianOptionsArgs].
 */
@PulumiTagMarker
public class ConfigurationSetVdmOptionsGuardianOptionsArgsBuilder internal constructor() {
    private var optimizedSharedDelivery: Output<String>? = null

    /**
     * @param value Specifies the status of your VDM optimized shared delivery. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("deutlrfhmfhlkwym")
    public suspend fun optimizedSharedDelivery(`value`: Output<String>) {
        this.optimizedSharedDelivery = value
    }

    /**
     * @param value Specifies the status of your VDM optimized shared delivery. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("jsuattqaivbeqpem")
    public suspend fun optimizedSharedDelivery(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.optimizedSharedDelivery = mapped
    }

    internal fun build(): ConfigurationSetVdmOptionsGuardianOptionsArgs =
        ConfigurationSetVdmOptionsGuardianOptionsArgs(
            optimizedSharedDelivery = optimizedSharedDelivery,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sesv2/kotlin/inputs/ConfigurationSetVdmOptionsGuardianOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sesv2.kotlin.inputs

import com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property optimizedSharedDelivery Specifies the status of your VDM optimized shared delivery. Valid values: `ENABLED`, `DISABLED`.
 */
public data class ConfigurationSetVdmOptionsGuardianOptionsArgs(
    public val optimizedSharedDelivery: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs> {
    override fun toJava(): com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs =
        com.pulumi.aws.sesv2.inputs.ConfigurationSetVdmOptionsGuardianOptionsArgs.builder()
            .optimizedSharedDelivery(optimizedSharedDelivery?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConfigurationSetVdmOptionsGuardianOptionsArgs].
 */
@PulumiTagMarker
public class ConfigurationSetVdmOptionsGuardianOptionsArgsBuilder internal constructor() {
    private var optimizedSharedDelivery: Output<String>? = null

    /**
     * @param value Specifies the status of your VDM optimized shared delivery. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("ycmskxeldlptyvck")
    public suspend fun optimizedSharedDelivery(`value`: Output<String>) {
        this.optimizedSharedDelivery = value
    }

    /**
     * @param value Specifies the status of your VDM optimized shared delivery. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("sebcyckouckqgrge")
    public suspend fun optimizedSharedDelivery(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.optimizedSharedDelivery = mapped
    }

    internal fun build(): ConfigurationSetVdmOptionsGuardianOptionsArgs =
        ConfigurationSetVdmOptionsGuardianOptionsArgs(
            optimizedSharedDelivery = optimizedSharedDelivery,
        )
}
